class KakeiboxRequest(object):
    input_serializer = None
    input = None
    input_serialized = None
    command = None
    command_response = None
    presenter = None
    presenter_output = None
